@@ -44,14 +44,14 @@ namespace Kwave
 	 *        vertically into the widget; if false the image will be
 	 *        cut off at the edge and should be scrolled
 	 */
-	explicit ImageView(QWidget *parent = 0,
-	                   bool fit_width = true,
+        explicit ImageView(QWidget *parent = Q_NULLPTR,
+	                   bool fit_width  = true,
 	                   bool fit_height = true);
 
 	/**
 	 * Destructor
 	 */
-	virtual ~ImageView();
+        virtual ~ImageView() Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns the position and size of the current image, packed
@@ -81,11 +81,11 @@ namespace Kwave
 
     protected:
 
-	void mouseMoveEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        virtual void mouseMoveEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
 
-	void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        virtual void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
 
-	void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+        virtual void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
 
     private:
 	/**
