@@ -45,17 +45,18 @@ namespace Kwave
 	StringEnterPlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
-	virtual ~StringEnterPlugin();
+        virtual ~StringEnterPlugin() Q_DECL_OVERRIDE;
 
 	/** @see Kwave::Plugin::load() */
-	void load(QStringList &params) Q_DECL_OVERRIDE;
+        virtual void load(QStringList &params) Q_DECL_OVERRIDE;
 
 	/**
 	 * Shows a dialog for a command that will be emitted through
 	 * sigCommand if OK has been pressed.
 	 * @see Kwave::Plugin::setup
 	 */
-	QStringList *setup(QStringList &previous_params) Q_DECL_OVERRIDE;
+        virtual QStringList *setup(QStringList &previous_params)
+            Q_DECL_OVERRIDE;
 
     };
 }
